EventTimePrecision

Enum EventTimePrecision 

pub enum EventTimePrecision {
    MilliSeconds,
    MicroSeconds,
    NanoSeconds,
}
Controls the time precisions of events.

Times are always logged in units of whole milliseconds with optional precision, determining the number of decimal places output by the serializer.

Variants



MilliSeconds

Logging may contain 1 decimal place to ensure float serialization e.g., 1.0, 2.0,



MicroSeconds

Logged up to 3 decimal places e.g., 1.234, 2.001



NanoSeconds

Logged up to 6 decimal places e.g., 1.234567, 2.001001